![logo](./readme_img/pyrheadb_logo.png)
Repository for the Python package intended to facilitate access to Rhea data from Python.

[![PyPI - Version](https://img.shields.io/pypi/v/pyrheadb.svg?logo=pypi&label=PyPI&logoColor=silver)](https://pypi.org/project/pyrheadb/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyrheadb.svg?logo=python&label=Python&logoColor=silver)](https://pypi.org/project/pyrheadb/)
[![license](https://img.shields.io/pypi/l/pyrheadb.svg?color=%2334D058)](https://github.com/sib-swiss/pyrheadb/blob/main/LICENSE)
![OS linux](https://img.shields.io/badge/OS-Linux-green)

[![Tests](https://github.com/sib-swiss/pyrheadb/actions/workflows/test.yml/badge.svg)](https://github.com/sib-swiss/pyrheadb/actions/workflows/test.yml)
[![Coverage Status](https://coveralls.io/repos/github/sib-swiss/pyrheadb/badge.svg?branch=main)](https://coveralls.io/github/sib-swiss/pyrheadb?branch=main)

Installation and usage
======================

```bash
pip install pyrheadb
```

> You might

Check [Wiki](https://github.com/sib-swiss/pyrheadb/wiki) for info about installation and usage.


Folder description
==================

## examples
[Jupyter notebooks](examples) containing Rhea analysis using the pyrheadb examples.

## src
Python source code for pyrheadb

## tests
Unit tests for each class of pyrheadb
